pub fn sign_authorization(
key: &SigningKey,
chain_id: U256,
address: H160,
nonce: U256,
) -> AuthorizationListEntryExpand description
Sign an authorization entry
This is a helper function for benchmarks and tests.
pub fn sign_authorization(
key: &SigningKey,
chain_id: U256,
address: H160,
nonce: U256,
) -> AuthorizationListEntrySign an authorization entry
This is a helper function for benchmarks and tests.